summaryrefslogtreecommitdiff
path: root/build/parsePrep.c
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2002-07-08 14:21:26 +0000
committerjbj <devnull@localhost>2002-07-08 14:21:26 +0000
commit241fad12870c58bd76468267f2816d409dbc7e57 (patch)
tree74806f5c8a6c458ba922b6df8550dfed0d3918c3 /build/parsePrep.c
parenta273ea6a095daa16e663d96e474c75115c3c2bdc (diff)
downloadrpm-241fad12870c58bd76468267f2816d409dbc7e57.tar.gz
rpm-241fad12870c58bd76468267f2816d409dbc7e57.tar.bz2
rpm-241fad12870c58bd76468267f2816d409dbc7e57.zip
Propagate splint-3.0.1.7 close(2) internalState annotation throughout.
CVS patchset: 5542 CVS date: 2002/07/08 14:21:26
Diffstat (limited to 'build/parsePrep.c')
-rw-r--r--build/parsePrep.c24
1 files changed, 11 insertions, 13 deletions
diff --git a/build/parsePrep.c b/build/parsePrep.c
index a6d9f4113..7b3172494 100644
--- a/build/parsePrep.c
+++ b/build/parsePrep.c
@@ -36,8 +36,8 @@
* @return 0 on success
*/
static int checkOwners(const char * urlfn)
- /*@globals fileSystem @*/
- /*@modifies fileSystem @*/
+ /*@globals fileSystem, internalState @*/
+ /*@modifies fileSystem, internalState @*/
{
struct stat sb;
@@ -67,9 +67,8 @@ static int checkOwners(const char * urlfn)
/*@-boundswrite@*/
/*@observer@*/ static char *doPatch(Spec spec, int c, int strip, const char *db,
int reverse, int removeEmpties)
- /*@globals rpmGlobalMacroContext,
- fileSystem@*/
- /*@modifies rpmGlobalMacroContext, fileSystem @*/
+ /*@globals rpmGlobalMacroContext, fileSystem, internalState @*/
+ /*@modifies rpmGlobalMacroContext, fileSystem, internalState @*/
{
const char *fn, *urlfn;
static char buf[BUFSIZ];
@@ -162,9 +161,8 @@ static int checkOwners(const char * urlfn)
*/
/*@-boundswrite@*/
/*@observer@*/ static const char *doUntar(Spec spec, int c, int quietly)
- /*@globals rpmGlobalMacroContext,
- fileSystem@*/
- /*@modifies rpmGlobalMacroContext, fileSystem @*/
+ /*@globals rpmGlobalMacroContext, fileSystem, internalState @*/
+ /*@modifies rpmGlobalMacroContext, fileSystem, internalState @*/
{
const char *fn, *urlfn;
static char buf[BUFSIZ];
@@ -281,10 +279,9 @@ static int checkOwners(const char * urlfn)
* @return 0 on success
*/
static int doSetupMacro(Spec spec, char *line)
- /*@globals rpmGlobalMacroContext,
- fileSystem@*/
+ /*@globals rpmGlobalMacroContext, fileSystem, internalState @*/
/*@modifies spec->buildSubdir, spec->macros, spec->prep,
- rpmGlobalMacroContext, fileSystem @*/
+ rpmGlobalMacroContext, fileSystem, internalState @*/
{
char buf[BUFSIZ];
StringBuf before;
@@ -441,8 +438,9 @@ static int doSetupMacro(Spec spec, char *line)
/*@-boundswrite@*/
static int doPatchMacro(Spec spec, char *line)
/*@globals rpmGlobalMacroContext,
- fileSystem@*/
- /*@modifies spec->prep, rpmGlobalMacroContext, fileSystem @*/
+ fileSystem, internalState @*/
+ /*@modifies spec->prep, rpmGlobalMacroContext,
+ fileSystem, internalState @*/
{
char *opt_b;
int opt_P, opt_p, opt_R, opt_E;